@@ -120,6 +120,9 @@ def _create_template_stream(
         include_node_pod_operator=(
             Path(__file__).parent / "operators/node_pod.py"
         ).read_text(),
+        include_spark_submit_k8s_operator=(
+            Path(__file__).parent / "operators/spark_submit_k8s.py"
+        ).read_text(),
         secrets=context_helper.config.run_config.secrets,
         macro_params=context_helper.config.run_config.macro_params,
         variables_params=context_helper.config.run_config.variables_params,
